@@ -2,15 +2,17 @@
 #'
 #' Create a new batch. 
 #' 
-#' @param batch_name name of the batch
+#' @param batch_name name of the batch; Required; character
+#' 
+#' @return List of length 26. Includes information like created_by, user_id, etc.
+#' 
 #' @export
-#' @references \url{https://shreddr.captricity.com/developer/}
+#' @references \url{https://shreddr.captricity.com/developer/api-reference/#v1-batch}
 #' @examples \dontrun{
 #' create_batch(batch_name="name_of_batch")
 #' }
 
-create_batch <- function(batch_name="")
-{
+create_batch <- function(batch_name="") {
     
     captr_CHECKAUTH()
   
@@ -23,5 +25,6 @@ create_batch <- function(batch_name="")
     tag        <- fromJSON(rawToChar(tag_con$content))
     tag
     return(invisible(tag))
+}
+
 
-}
\ No newline at end of file
